@@ -13,7 +13,9 @@ class Config(object):
 class DevelopmentConfig(Config):
 
     DEBUG = True
-    SQLALCHEMY_DATABASE_URI = 'sqlite:///app_auto_test.db'
+    basedir = os.path.abspath(os.path.dirname(__file__))
+    SQLALCHEMY_DATABASE_URI = 'sqlite:///' + basedir + '/instance/app_auto_test.db'
+    # SQLALCHEMY_DATABASE_URI = 'sqlite:///app_auto_test.db'
 
 config = {
     'development':DevelopmentConfig,
